where

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 7, 2023 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package for finding directories and files related to the app

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Aliases

func Aliases() string

get the `alias.json` file where info about aliases is stored

func Bin

func Bin() string

get the `bin` directory, this is where the current active version is stored

func Home

func Home() string

find user home dir. In our case, we panic when we can't get it

func Installations

func Installations() string

get installations directory

func RootDir

func RootDir() string

app root dir

func SetRoot

func SetRoot(path string)

set root dir

func VersionCache

func VersionCache() string

version cache file

Types

This section is empty.

Jump to