versions

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 7, 2023 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func List

func List() ([]string, error)

list all versions

this uses the local versions cache file, if its stale or does not exist, it generates the file and then uses it

func SafeVStr

func SafeVStr(version string) string

remove that `v` in from of a version

func VersionArchiveUrl

func VersionArchiveUrl(version string, arch string) string

generate url to the archive for a specific version

Types

This section is empty.

Jump to