Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func List ¶
list all versions
this uses the local versions cache file, if its stale or does not exist, it generates the file and then uses it
func VersionArchiveUrl ¶
generate url to the archive for a specific version
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.